// rustfmt-normalize_comments: true
// FIXME(#919)

trait NameC {
    // comment
}
struct FooC {
    // comment
}
enum MooC {
    // comment
}
mod BarC {
    // comment
}
extern "C" {
    // comment
}
